<!DOCTYPE html>
<html class="no-js" lang="en" >
  <head>
    {% load staticfiles %}
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=no">
    <meta content="telephone=no" name="format-detection" />
    <title>{% block title %}红包{% endblock %}</title>
    <link rel="stylesheet" href="http://cdn.bootcss.com/foundation/6.1.2/foundation-flex.min.css">
  </head>
  <body>
    {% block main %}
    {% endblock %}
  </body>
</html>
